@@ -26,11 +26,15 @@ def process_arguments():
     """ Check and extract arguments provided. """
     parser = argparse.ArgumentParser(allow_abbrev=False)
     group = parser.add_mutually_exclusive_group()
-    group.add_argument("--export", action="store_true")
+    group.add_argument("--export", action="store_true", help="export credentials as environment variables")
+    group.add_argument("--generate", action="store_true", help="generate credentials file from the input profile")
     group.add_argument("--process", action="store_true")
     group.add_argument("--exec", action="store")
     profile_from_envvar = os.environ.get("AWS_PROFILE", os.environ.get("AWS_DEFAULT_PROFILE", None))
-    parser.add_argument("--profile", action="store", default=profile_from_envvar)
+    parser.add_argument("--profile", action="store", default=profile_from_envvar, help="the source profile to use for creating credentials")
+    parser.add_argument("--outprofile", action="store", default="default", help="the destination profile to save generated credentials")
+    parser.add_argument("--configfile", action="store", default="~/.aws/config", help="the config file to append resulting config")
+    parser.add_argument("--credentialsfile", action="store", default="~/.aws/credentials", help="the credentials file to append resulting credentials")
     parser.add_argument("command", action="store", nargs=argparse.REMAINDER, help="a command that you want to wrap")
     args = parser.parse_args()
     return args
@@ -51,7 +55,7 @@ def retrieve_profile(profile_name):
         config_path = os.path.abspath(os.path.expanduser("~/.aws/config"))
     config = configparser.ConfigParser()
     config.read(config_path)
-    
+
     if profile_name == "default":
         section_name = "default"
     else:
@@ -186,7 +190,7 @@ def get_assumed_role_credentials(profile):
     if result.returncode != 0:
         print(result.stderr.decode(), file=sys.stderr)
         sys.exit("Failed to assume-role %s" % retrieve_attribute(profile, "role_arn"))
-    
+
     output = json.loads(result.stdout)
     return {
         "roleCredentials": {
@@ -198,6 +202,36 @@ def get_assumed_role_credentials(profile):
     }
 
 
+def process_cred_generation(
+    credentialsfile, configfile, expiration, outprofile,
+    access_key, secret_access_key, session_token, profile):
+    """ Export the credentials and config """
+
+    config = configparser.ConfigParser()
+    config.read(credentialsfile)
+    config[outprofile] = {
+        "aws_access_key_id": access_key,
+        "aws_secret_access_key": secret_access_key,
+        "aws_session_token": session_token
+    }
+    with open(credentialsfile, "w") as file:
+        config.write(file)
+
+    config.read(configfile)
+    new_config = {}
+    if "region" in profile:
+        new_config = {
+            "region": retrieve_attribute(profile, "region")
+        }
+    config[outprofile] = new_config
+    with open(configfile, "w") as file:
+        config.write(file)
+
+    print("Credentials written to %s" % credentialsfile)
+    print("Configuration written to %s" % configfile)
+    print("The credentials will expire at %s" % expiration)
+
+
 def main():
     """ Main! """
     args = process_arguments()
@@ -205,7 +239,7 @@ def main():
         sys.exit("Please specify profile name by --profile or environment variable AWS_PROFILE")
 
     profile = retrieve_profile(args.profile)
-    
+
     if "source_profile" in profile:
         grc_structure = get_assumed_role_credentials(profile)
     else:
@@ -220,9 +254,14 @@ def main():
         print("export AWS_ACCESS_KEY_ID=\"%s\"" % access_key)
         print("export AWS_SECRET_ACCESS_KEY=\"%s\"" % secret_access_key)
         print("export AWS_SESSION_TOKEN=\"%s\"" % session_token)
-        # If region is specified in profile, also export AWS_REGION
-        if "region" in profile:
-            print("export AWS_REGION=\"%s\"" % retrieve_attribute(profile, "region"))
+        # If region is specified in profile, also export AWS_DEFAULT_REGION
+        if "AWS_DEFAULT_REGION" not in os.environ and "region" in profile:
+            print("export AWS_DEFAULT_REGION=\"%s\"" % retrieve_attribute(profile, "region"))
+    elif args.generate:
+        if args.outprofile is not None:
+            process_cred_generation(
+                args.credentialsfile, args.configfile, expiration, args.outprofile,
+                access_key, secret_access_key, session_token, profile)
     elif args.process:
         output = {
             "Version": 1,
@@ -236,17 +275,20 @@ def main():
         os.environ["AWS_ACCESS_KEY_ID"] = access_key
         os.environ["AWS_SECRET_ACCESS_KEY"] = secret_access_key
         os.environ["AWS_SESSION_TOKEN"] = session_token
-        # If region is specified in profile, also set AWS_REGION
-        if "region" in profile:
-            os.environ["AWS_REGION"] = retrieve_attribute(profile, "region")
+        status = None # ensure this is initialised
+        # If region is specified in profile, also set AWS_DEFAULT_REGION
+        if "AWS_DEFAULT_REGION" not in os.environ and "region" in profile:
+            os.environ["AWS_DEFAULT_REGION"] = retrieve_attribute(profile, "region")
         if args.exec is not None:
             status = os.system(args.exec)
         elif args.command is not None:
             status = os.system(" ".join(args.command))
         # The return value of os.system is not simply the exit code of the process
         # see: https://mail.python.org/pipermail/python-list/2003-May/207712.html
+        # noinspection PyUnboundLocalVariable
         if status is None:
             sys.exit(0)
+        # noinspection PyUnboundLocalVariable
         if status % 256 == 0:
             sys.exit(status//256)
         sys.exit(status % 256)
